==> jc-1.4.0.tar.gz: java/awt/event/ItemEvent.h <==
// public class java.awt.event.ItemEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class 30307446b8b5e761 java_awt_event_ItemEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_ItemEvent_H_
#define _JC_java_awt_event_ItemEvent_H_

// Forward structure declarations
struct _jc_java_awt_ItemSelectable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_ItemEvent$sub_refs	_jc_java_awt_event_ItemEvent$sub_refs;
typedef struct _jc_java_awt_event_ItemEvent$sub_nonrefs	_jc_java_awt_event_ItemEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_ItemEvent$refs	_jc_java_awt_event_ItemEvent$refs;
typedef struct _jc_java_awt_event_ItemEvent$nonrefs	_jc_java_awt_event_ItemEvent$nonrefs;
typedef struct _jc_java_awt_event_ItemEvent$object	_jc_java_awt_event_ItemEvent$object;

typedef struct _jc_java_awt_event_ItemEvent$fields_struct	_jc_java_awt_event_ItemEvent$fields_struct;
typedef const struct _jc_java_awt_event_ItemEvent$vmethods	_jc_java_awt_event_ItemEvent$vmethods;
typedef const struct _jc_java_awt_event_ItemEvent$vtable	_jc_java_awt_event_ItemEvent$vtable;
typedef const struct _jc_java_awt_event_ItemEvent$vtype	_jc_java_awt_event_ItemEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_ItemEvent$fields_struct {
	jlong	serialVersionUID;
	jint	DESELECTED;
	jint	ITEM__5fFIRST;
	jint	ITEM__5fLAST;
	jint	ITEM__5fSTATE__5fCHANGED;
	jint	SELECTED;
};
extern _jc_java_awt_event_ItemEvent$fields_struct _jc_java_awt_event_ItemEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_ItemEvent$method$_init$1d6758609df7ca00(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *, struct _jc_object *, jint, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_event_ItemEvent$method$getItem$79c9f5e44e700b06(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *);
extern struct _jc_object *_jc_java_awt_event_ItemEvent$method$getItemSelectable$f86f8af12a20cda9(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *);
extern jint _jc_java_awt_event_ItemEvent$method$getStateChange$747f7b05af170c4e(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ItemEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ItemEvent$method_info$getItem$79c9f5e44e700b06;
extern _jc_method _jc_java_awt_event_ItemEvent$method_info$getItemSelectable$f86f8af12a20cda9;
extern _jc_method _jc_java_awt_event_ItemEvent$method_info$getStateChange$747f7b05af170c4e;
extern _jc_method _jc_java_awt_event_ItemEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_ItemEvent$vmethods {
	struct _jc_java_lang_Object$object	*(*getItem$79c9f5e44e700b06)(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *);
	struct _jc_object	*(*getItemSelectable$f86f8af12a20cda9)(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *);
	jint	(*getStateChange$747f7b05af170c4e)(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *);
};

// Vtable
struct _jc_java_awt_event_ItemEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ItemEvent$vmethods	java_awt_event_ItemEvent;
};

// Vtype
struct _jc_java_awt_event_ItemEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_ItemEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ItemEvent$sub_refs {
	struct _jc_java_lang_Object$object	*item;
};

// Reference instance fields (object)
struct _jc_java_awt_event_ItemEvent$refs {
    _jc_java_awt_event_ItemEvent$sub_refs	java_awt_event_ItemEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ItemEvent$sub_nonrefs {
	jint	stateChange;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ItemEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ItemEvent$sub_nonrefs	java_awt_event_ItemEvent;
};

// Object instance structure
struct _jc_java_awt_event_ItemEvent$object {
	_jc_java_awt_event_ItemEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ItemEvent$vtype	*vtype;
	_jc_java_awt_event_ItemEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ItemEvent$vtype _jc_java_awt_event_ItemEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ItemEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ItemEvent$class_object;

#endif	/* _JC_java_awt_event_ItemEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/ItemEvent.h <==
// public class java.awt.event.ItemEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class 30307446b8b5e761 java_awt_event_ItemEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_ItemEvent_H_
#define _JC_java_awt_event_ItemEvent_H_

// Forward structure declarations
struct _jc_java_awt_ItemSelectable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_ItemEvent$sub_refs	_jc_java_awt_event_ItemEvent$sub_refs;
typedef struct _jc_java_awt_event_ItemEvent$sub_nonrefs	_jc_java_awt_event_ItemEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_ItemEvent$refs	_jc_java_awt_event_ItemEvent$refs;
typedef struct _jc_java_awt_event_ItemEvent$nonrefs	_jc_java_awt_event_ItemEvent$nonrefs;
typedef struct _jc_java_awt_event_ItemEvent$object	_jc_java_awt_event_ItemEvent$object;

typedef struct _jc_java_awt_event_ItemEvent$fields_struct	_jc_java_awt_event_ItemEvent$fields_struct;
typedef const struct _jc_java_awt_event_ItemEvent$vmethods	_jc_java_awt_event_ItemEvent$vmethods;
typedef const struct _jc_java_awt_event_ItemEvent$vtable	_jc_java_awt_event_ItemEvent$vtable;
typedef const struct _jc_java_awt_event_ItemEvent$vtype	_jc_java_awt_event_ItemEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_ItemEvent$fields_struct {
	jlong	serialVersionUID;
	jint	DESELECTED;
	jint	ITEM__5fFIRST;
	jint	ITEM__5fLAST;
	jint	ITEM__5fSTATE__5fCHANGED;
	jint	SELECTED;
};
extern _jc_java_awt_event_ItemEvent$fields_struct _jc_java_awt_event_ItemEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_ItemEvent$method$_init$1d6758609df7ca00(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *, struct _jc_object *, jint, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_event_ItemEvent$method$getItem$79c9f5e44e700b06(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_event_ItemEvent$method$getItemSelectable$f86f8af12a20cda9(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_ItemEvent$method$getStateChange$747f7b05af170c4e(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ItemEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ItemEvent$method_info$getItem$79c9f5e44e700b06;
extern _jc_method _jc_java_awt_event_ItemEvent$method_info$getItemSelectable$f86f8af12a20cda9;
extern _jc_method _jc_java_awt_event_ItemEvent$method_info$getStateChange$747f7b05af170c4e;
extern _jc_method _jc_java_awt_event_ItemEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_ItemEvent$vmethods {
	struct _jc_java_lang_Object$object	*(*getItem$79c9f5e44e700b06)(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getItemSelectable$f86f8af12a20cda9)(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
	jint	(*getStateChange$747f7b05af170c4e)(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_ItemEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ItemEvent$vmethods	java_awt_event_ItemEvent;
};

// Vtype
struct _jc_java_awt_event_ItemEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_ItemEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ItemEvent$sub_refs {
	struct _jc_java_lang_Object$object	*item;
};

// Reference instance fields (object)
struct _jc_java_awt_event_ItemEvent$refs {
    _jc_java_awt_event_ItemEvent$sub_refs	java_awt_event_ItemEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ItemEvent$sub_nonrefs {
	jint	stateChange;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ItemEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ItemEvent$sub_nonrefs	java_awt_event_ItemEvent;
};

// Object instance structure
struct _jc_java_awt_event_ItemEvent$object {
	_jc_java_awt_event_ItemEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ItemEvent$vtype	*vtype;
	_jc_java_awt_event_ItemEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ItemEvent$vtype _jc_java_awt_event_ItemEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ItemEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ItemEvent$class_object;

#endif	/* _JC_java_awt_event_ItemEvent_H_ */
